//
// JTypist v3.0 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// AExerciseGUIStats class - creates a dialog with lesson completion
// statistics displayed
//
import java.awt.*;
import java.applet.*;

public class AExerciseGUIStats extends Frame {
	private boolean inAnApplet = true;

	// GUI components
	private Label lesson_label;
	private Label stats_label;
	private Label stats_label2;
	private Button ok_button;

	// constructor initializes the whole GUI set
	public AExerciseGUIStats( boolean inAnApplet ) {
		this.inAnApplet = inAnApplet;

		// create GUI components
		setTitle( "Typist v3.0 Exercise Timings" );
		setLayout( new BorderLayout() );

		// create the labels
		Panel label_panel = new Panel();
		label_panel.setLayout( new GridLayout( 0, 1 ));
		lesson_label = new Label();
		label_panel.add( lesson_label );
		stats_label = new Label();
		label_panel.add( stats_label );
		stats_label2 = new Label();
		label_panel.add( stats_label2 );
		add( "Center", label_panel );

		Panel button_panel = new Panel();
		button_panel.setLayout( new FlowLayout() );
		ok_button = new Button( "Ok" );
		button_panel.add ( ok_button );
		add( "South", button_panel );
	}


	// show a specific single set of statistics for a specific lesson
	public void show( Lesson lesson, KeyStatistics key_stats ) {

		// update the labels with the details passed in
		lesson_label.setText( "Exercise '" + lesson.title + "' completed:" );
		int total_keystrokes = key_stats.get_strikes()
				+ key_stats.get_misses();
		stats_label.setText( "You made "
			+ total_keystrokes + " timed keystrokes, with "
			+ key_stats.get_pc_accuracy() + "% accuracy" );
		stats_label2.setText( "Your speed was "
			+ key_stats.get_WPM( false ) + " WPM, "
			+ key_stats.get_WPM( true ) + " WPM adjusted " );

		// call pack to resize the dialog box, then show
		pack(); show();
	}


	// handle dismiss, close, etc by just hiding ourselves
	private void handle_ok_button() {

		// simply just hide this frame from view
		hide();
	}


	// handle GUI component actions and events
	public boolean action( Event evt, Object arg ) {
		if ( evt.target instanceof Button ) {
			if ( evt.target == ok_button ) {
				handle_ok_button();
			}
		}
		return ( false );
	}
	public boolean handleEvent( Event evt ) {
		if ( evt.id == Event.WINDOW_DESTROY ) {
			handle_ok_button();
		}
		return ( super.handleEvent( evt ));
	}


	// test code
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );
		AExerciseGUIStats stats = new AExerciseGUIStats( false );
		stats.pack();
		KeyStatistics s = new KeyStatistics();
		s.struck( 300 ); s.struck( 200 ); s.struck( 100 );
		s.missed( 400 );
		stats.show( new Lesson( Lesson.DRILL, "Test lesson", "", "" ),
				s );
	}
}
