//
// JTypist v3.0 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// Gauge class - implements a Windows-style gauge GUI component
//
import java.applet.*;
import java.awt.*;

public class Gauge extends Canvas {

	// the gauge current value, range, units, and preferred size
	private int range_min = 0;
	private int range_max = 100;
	private int value = 0;
	private String units = "%";
	Dimension pref_size = new Dimension( 40, 18 );


	// constructors to create a gauge
	public Gauge() {}
	public Gauge( int range_min, int range_max, int value, String units ) {
		this.range_min = range_min;
		this.range_max = range_max;
		this.value = value;
		this.units = units;
	}

	// return dimensions, and paint the graphic
	public Dimension preferredSize() { return ( pref_size ); }
	public Dimension minimumSize() { return ( pref_size ); }
	public void paint( Graphics g ) {
		Dimension d = size();

		// start with a small box round the gauge canvas
		g.setColor( getBackground() );
		g.draw3DRect( 0, 0, d.width - 1, d.height - 1, false );

		// calculate the fill width, and reset its bounds if
		// it could be outside the allowed area
		int fill_width = (( d.width - 4 ) * ( value - range_min ))
					/ ( range_max - range_min );
		if ( fill_width < 0 )
			fill_width = 0;
		else if ( fill_width > d.width - 4 )
			fill_width = d.width - 4;

		// plot in the gauge value
		g.setColor( getForeground() );
		g.fillRect( 2, 2, fill_width, d.height - 4 );

		// write the numeric value centrally in the gauge
		FontMetrics fm = g.getFontMetrics();
		String svalue = Integer.toString( value ) + units;
		// why does setXORMode not work with drawString ???
		g.setColor( Color.white );
		g.drawString( svalue,
				( d.width - fm.stringWidth( svalue )) / 2,
				( d.height + fm.getAscent() ) / 2 );
	}


	// standard get/set methods
	public int get_min() { return ( range_min ); }
	public int get_max() { return ( range_max ); }
	public int get_value() { return ( value ); }
	public String get_units() { return ( units ); }
	public void set_min( int range_min ) {
		this.range_min = range_min; repaint();
	}
	public void set_max( int range_max ) {
		this.range_max = range_max; repaint();
	}
	public void set_value( int value ) {
		this.value = value; repaint();
	}
	public void set_units( String units ) {
		this.units = units; repaint();
	}


	// test code
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		Frame frame = new Frame();
		Gauge gauge = new Gauge();
		gauge.setForeground( Color.red );
		frame.setLayout( new BorderLayout() );
		frame.add( "Center", gauge );
		frame.pack(); frame.show();
		for ( int i = -10; i <= 110; i++ ) {
			gauge.set_value( i );
			try { Thread.sleep( 500 ); }
			catch( Exception e ) {}
		}
	}
}
