//
// JTypist v3.0 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// HelpGUI class - creates a frame to display some online help
//
import java.awt.*;
import java.applet.*;

public class HelpGUI extends Frame {
	private boolean inAnApplet = true;

	// the help text itself
	private final String help_text[] = HelpText.data;
	private String unHTML_help_text[];

	// menubar GUI components
	private MenuBar menu_bar;
	private Menu file_menu;
	private MenuItem file_close;

	// GUI components
	private Choice topic_choice;
	private TextArea text_area;

	// constructor initializes the whole GUI set
	public HelpGUI( boolean inAnApplet ) {
		this.inAnApplet = inAnApplet;

		// generate an unHTMLified copy of the help text;
		// just do it once, not every time we want to show
		// some text
		unHTML_help_text = new String[ help_text.length ];
		for ( int index = 0; index < help_text.length; index++ ) {
			unHTML_help_text[ index ] =
					unHTML( help_text[ index ]);
		}

		// create GUI components
		setTitle( "Typist v3.0 Help Window" );
		setLayout( new BorderLayout() );

		// create the menu bar stuff
		menu_bar = new MenuBar();
		setMenuBar( menu_bar );
		// File menu
		file_menu = new Menu( "File" );
		menu_bar.add( file_menu );
		file_close = new MenuItem( "Close Window" );
		file_menu.add( file_close );

		// create the text display
		text_area = new TextArea( 12, 80 );
		text_area.setBackground( Color.white );
		text_area.setEditable( false );
		add( "Center", text_area );

		// add topic choice as a toolbar item
		Panel toolbar = new Panel();
		toolbar.setLayout( new BorderLayout() );
		add( "North", toolbar );

		Panel controls = new Panel();
		controls.setLayout( new FlowLayout() );
		toolbar.add( "West", controls );
		controls.add( new Label( "Select a help topic:" ));
		topic_choice = new Choice();
		controls.add( topic_choice );

		// build up the choice of topics
		for ( int index = 0; index < unHTML_help_text.length; index++ ) {
			topic_choice.addItem( get_topic_name(
					unHTML_help_text[ index ]));
		}

		// act as if choice 0 selected
		topic_choice.select( 0 );
		handle_topic_selection();
	}


	// convenience functions to find topic_name and topic_text
	// from a help topic string
	private String get_topic_name( String s ) {
		return ( s.substring( 0, s.indexOf( "\n" )));
	}
	private String get_topic_text( String s ) {
		return ( s.substring( s.indexOf( "\n" ) + 1, s.length() ));
	}


	// take out the HTML elements from a help string - we
	// don't do them here
	private String unHTML( String s ) {
		String ret_string = "";

		// pass over the string removing HTML <> stuff and
		// translating &...; items (awk would be nice here...)
		boolean in_html_tag = false;
		for ( int index = 0; index < s.length(); index++ ) {
			if ( index < s.length() - 4 &&
					s.regionMatches( index, "&lt;", 0, 4 )) {
				ret_string += "<"; index += 3; continue;
			}
			else if ( index < s.length() - 4 &&
					s.regionMatches( index, "&gt;", 0, 4 )) {
				ret_string += ">"; index += 3; continue;
			}
			else if ( index < s.length() - 5 &&
					s.regionMatches( index, "&amp;", 0, 5 )) {
				ret_string += "&"; index += 4; continue;
			}
			else if ( index < s.length() - 6 &&
					s.regionMatches( index, "&quot;", 0, 6 )) {
				ret_string += "\""; index += 5; continue;
			}
			else {
				String c = s.substring( index, index + 1 );
				if ( c.equals( "<" )) {
					in_html_tag = true; continue;
				}
				else if ( c.equals( ">" )) {
					in_html_tag = false; continue;
				}
				else if ( ! in_html_tag )
					ret_string += c;
			}
		}
		return ( ret_string );
	}


	// handle dismiss, close, etc by just hiding ourselves
	private void handle_close_button() {

		// simply just hide this frame from view
		hide();
	}


	// handle the selection of a new series
	private void handle_topic_selection() {

		// just display the text for the selected topic
		text_area.setText( get_topic_text(
			unHTML_help_text[ topic_choice.getSelectedIndex() ]));
	}


	// handle GUI component actions and events
	public boolean action( Event evt, Object arg ) {
		if ( evt.target instanceof Choice ) {
			handle_topic_selection();
		}
		else if ( evt.target instanceof MenuItem ) {
			if ( evt.target == file_close )
				handle_close_button();
		}
		return ( false );
	}
	public boolean handleEvent( Event evt ) {
		if ( evt.id == Event.WINDOW_DESTROY ) {
			handle_close_button();
		}
		return ( super.handleEvent( evt ));
	}


	// test code
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );
		HelpGUI help = new HelpGUI( false );
		help.pack(); help.show();
	}
}
