//
// JTypist v3.0 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// HelpHTML class - glom of stuff to print online help as HTML
//

abstract public class HelpHTML {

	// string full of GNU GPL header
	private static final String GNUGPL =
  "<!--\n"
+ "  -- JTypist v3.0 - Java typing tutor program for UNIX system\n"
+ "  -- Copyright (C) 1998  Simon Baldwin (simonb@sco.com)\n"
+ "  --\n"
+ "  -- This program is free software; you can redistribute it and/or\n"
+ "  -- modify it under the terms of the GNU General Public License\n"
+ "  -- as published by the Free Software Foundation; either version 2\n"
+ "  -- of the License, or (at your option) any later version.\n"
+ "  --\n"
+ "  -- This program is distributed in the hope that it will be useful,\n"
+ "  -- but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+ "  -- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+ "  -- GNU General Public License for more details.\n"
+ "  --\n"
+ "  -- You should have received a copy of the GNU General Public License\n"
+ "  -- along with this program; if not, write to the Free Software\n"
+ "  -- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n"
+ "  --\n"
+ "  --  -->\n";


	// convenience functions to find topic_name and topic_text
	// from a help topic string
	private static String get_topic_name( String s ) {
		return ( s.substring( 0, s.indexOf( "\n" )));
	}
	private static String get_topic_text( String s ) {
		return ( s.substring( s.indexOf( "\n" ) + 1, s.length() ));
	}


	// print out a help text array as an HTML document
	public static String toHTML( String help_text[] ) {
		String ret_str = "";

		// write out the HTML header
		ret_str += "<HTML>\n";
		ret_str += GNUGPL;
		ret_str += "<HEAD>\n";
		ret_str += "<TITLE>Typist v3.0 (Java) User's Guide</TITLE>\n";
		ret_str += "</HEAD>\n<BODY BGCOLOR=\"#FFFFFF\">\n";
		ret_str += "<H1>Typist v3.0 (Java) User's Guide</H1>\n";
		ret_str += "<P>\n\n";

		// write out a contents section
		ret_str += "<H2>Table Of Contents</H2>\n";
		ret_str += "<P>\n\n";
		ret_str += "This document contains the following sections:\n";
		ret_str += "<OL>\n";
		for ( int index = 0; index < help_text.length; index++ ) {
			ret_str += "<LI><A HREF=\"#topic_" + index + "\">"
					+ get_topic_name( help_text[ index ])
					+ "</A></LI>\n";
				
		}
		ret_str += "</OL>\n<P>\n\n";

		// write out each topic from the help array
		for ( int index = 0; index < help_text.length; index++ ) {
			ret_str += "<H2><A NAME=\"topic_" + index + "\">"
					+ get_topic_name( help_text[ index ])
					+ "</A></H2>\n";
			ret_str += "<P>\n\n";
			ret_str += get_topic_text( help_text[ index ]);
			ret_str += "<P>\n\n";
		}

		// finish up
		ret_str += "</BODY>\n</HTML>\n";
		return ( ret_str );
	}


	// test code
	public static void main( String args[] ) {
		System.out.println( toHTML( HelpText.data ));
	}
}
