//
// JTypist v3.0 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// KBLayoutDvorak class - describes the Dvorak keyboard and its use
//

public abstract class KBLayoutDvorak implements KBLayoutable {

	// unique ID for the keyboard type
	public static final String kb_id = "Dvorak";

	// tabular list of keys, showing what character is given what
	// ID for the purposes of statistics monitoring, and what
	// finger is responsible for monitoring it
	public static final KeyData keymap_table[] = {
	new KeyData( '[',	RH_PINKY,	BASIC ),
	new KeyData( ']',	RH_PINKY,	BASIC ),
	new KeyData( '\\',	RH_PINKY,	BASIC ),
	new KeyData( '\'',	LH_PINKY,	BASIC ),
	new KeyData( ',',	LH_RING,	BASIC ),
	new KeyData( '.',	LH_MIDDLE,	BASIC ),
	new KeyData( '/',	RH_PINKY,	BASIC ),
	new KeyData( '=',	RH_PINKY,	BASIC ),
	new KeyData( '-',	RH_PINKY,	BASIC ),
	new KeyData( ';',	LH_PINKY,	BASIC ),
	new KeyData( '\n',	RH_PINKY,	BASIC ),
	new KeyData( ' ',	RH_THUMB,	BASIC ),
	new KeyData( '!',	LH_PINKY,	FIGURES ),
	new KeyData( '@',	LH_RING,	FIGURES ),
	new KeyData( '#',	LH_MIDDLE,	FIGURES ),
	new KeyData( '$',	LH_INDEX,	FIGURES ),
	new KeyData( '%',	LH_INDEX,	FIGURES ),
	new KeyData( '^',	RH_INDEX,	FIGURES ),
	new KeyData( '&',	RH_INDEX,	FIGURES ),
	new KeyData( '*',	RH_MIDDLE,	FIGURES ),
	new KeyData( '(',	RH_RING,	FIGURES ),
	new KeyData( ')',	RH_PINKY,	FIGURES ),
	new KeyData( '{',	RH_PINKY,	FIGURES ),
	new KeyData( '}',	RH_PINKY,	FIGURES ),
	new KeyData( '|',	RH_PINKY,	FIGURES ),
	new KeyData( '"',	LH_RING,	FIGURES ),
	new KeyData( '<',	LH_RING,	FIGURES ),
	new KeyData( '>',	LH_MIDDLE,	FIGURES ),
	new KeyData( '?',	RH_PINKY,	FIGURES ),
	new KeyData( '+',	RH_PINKY,	FIGURES ),
	new KeyData( '_',	RH_PINKY,	FIGURES ),
	new KeyData( ':',	LH_PINKY,	FIGURES ),
	new KeyData( '1',	LH_PINKY,	NUMERIC ),
	new KeyData( '2',	LH_RING,	NUMERIC ),
	new KeyData( '3',	LH_MIDDLE,	NUMERIC ),
	new KeyData( '4',	LH_INDEX,	NUMERIC ),
	new KeyData( '5',	LH_INDEX,	NUMERIC ),
	new KeyData( '6',	RH_INDEX,	NUMERIC ),
	new KeyData( '7',	RH_INDEX,	NUMERIC ),
	new KeyData( '8',	RH_MIDDLE,	NUMERIC ),
	new KeyData( '9',	RH_RING,	NUMERIC ),
	new KeyData( '0',	RH_PINKY,	NUMERIC ),
	new KeyData( 'P',	LH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'Y',	LH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'F',	RH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'G',	RH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'C',	RH_MIDDLE,	SHIFTED_ALPHA ),
	new KeyData( 'R',	RH_RING,	SHIFTED_ALPHA ),
	new KeyData( 'L',	RH_PINKY,	SHIFTED_ALPHA ),
	new KeyData( 'A',	LH_PINKY,	SHIFTED_ALPHA ),
	new KeyData( 'O',	LH_RING,	SHIFTED_ALPHA ),
	new KeyData( 'E',	LH_MIDDLE,	SHIFTED_ALPHA ),
	new KeyData( 'U',	LH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'I',	LH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'D',	RH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'H',	RH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'N',	RH_RING,	SHIFTED_ALPHA ),
	new KeyData( 'T',	RH_MIDDLE,	SHIFTED_ALPHA ),
	new KeyData( 'S',	RH_PINKY,	SHIFTED_ALPHA ),
	new KeyData( 'Q',	LH_RING,	SHIFTED_ALPHA ),
	new KeyData( 'J',	LH_MIDDLE,	SHIFTED_ALPHA ),
	new KeyData( 'K',	LH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'X',	LH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'B',	RH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'M',	RH_INDEX,	SHIFTED_ALPHA ),
	new KeyData( 'W',	RH_MIDDLE,	SHIFTED_ALPHA ),
	new KeyData( 'V',	RH_RING,	SHIFTED_ALPHA ),
	new KeyData( 'Z',	RH_PINKY,	SHIFTED_ALPHA ),
	new KeyData( 'p',	LH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'y',	LH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'f',	RH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'g',	RH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'c',	RH_MIDDLE,	UNSHIFTED_ALPHA ),
	new KeyData( 'r',	RH_RING,	UNSHIFTED_ALPHA ),
	new KeyData( 'l',	RH_PINKY,	UNSHIFTED_ALPHA ),
	new KeyData( 'a',	LH_PINKY,	UNSHIFTED_ALPHA ),
	new KeyData( 'o',	LH_RING,	UNSHIFTED_ALPHA ),
	new KeyData( 'e',	LH_MIDDLE,	UNSHIFTED_ALPHA ),
	new KeyData( 'u',	LH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'i',	LH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'd',	RH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'h',	RH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 't',	RH_MIDDLE,	UNSHIFTED_ALPHA ),
	new KeyData( 'n',	RH_RING,	UNSHIFTED_ALPHA ),
	new KeyData( 's',	RH_PINKY,	UNSHIFTED_ALPHA ),
	new KeyData( 'q',	LH_RING,	UNSHIFTED_ALPHA ),
	new KeyData( 'j',	LH_MIDDLE,	UNSHIFTED_ALPHA ),
	new KeyData( 'k',	LH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'x',	LH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'b',	RH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'm',	RH_INDEX,	UNSHIFTED_ALPHA ),
	new KeyData( 'w',	RH_MIDDLE,	UNSHIFTED_ALPHA ),
	new KeyData( 'v',	RH_RING,	UNSHIFTED_ALPHA ),
	new KeyData( 'z',	RH_PINKY,	UNSHIFTED_ALPHA )
	};
}
