//
// JTypist v3.0 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// LessonSeriesLibrary class - holds the complete set of lessons
//
public class LessonSeriesLibrary {

	// lesson series we can offer, in order
	public static final String series[] = {
		LessonSeriesQ.series, LessonSeriesR.series, LessonSeriesT.series,
		LessonSeriesV.series, LessonSeriesU.series, LessonSeriesD.series,
		LessonSeriesM.series, LessonSeriesS.series, LessonSeriesN.series
	};

	// note of the current lesson series in use
	private String cur_series;


	// constructors to initialize the current set offerings
	public LessonSeriesLibrary( String initial_series ) {

		// try to set this series, and if invalid just
		// ignore the initial one
		if ( ! set_series( initial_series ) )
			set_series( 0 );
	}
	public LessonSeriesLibrary() {

		// default constructor just offers the first thing we
		// have
		set_series( 0 );
	}


	// return information on the series offered
	public int get_num_series() {
		return ( series.length );
	}
	public String get_series( int index ) {
		return ( series[ index ] );
	}


	// set the current series
	public boolean set_series( int index ) {
		if ( index >= 0 && index < series.length ) {
			cur_series = series[ index ];
			return ( true );
		}
		return ( false );
	}
	public boolean set_series( String series_id ) {

		// search the series we know of for the one we want
		for ( int index = 0; index < series.length; index++ ) {
			if ( series_id.equals( series[ index ] ))
				return ( set_series( index ));
		}
		return ( false );
	}


	// get the fields of the current lessons set
	public String get_series() {
		return ( cur_series );
	}
	public String get_descr() {
		     if ( cur_series == LessonSeriesQ.series )
			return ( LessonSeriesQ.descr );
		else if ( cur_series == LessonSeriesR.series )
			return ( LessonSeriesR.descr );
		else if ( cur_series == LessonSeriesT.series )
			return ( LessonSeriesT.descr );
		else if ( cur_series == LessonSeriesV.series )
			return ( LessonSeriesV.descr );
		else if ( cur_series == LessonSeriesU.series )
			return ( LessonSeriesU.descr );
		else if ( cur_series == LessonSeriesD.series )
			return ( LessonSeriesD.descr );
		else if ( cur_series == LessonSeriesM.series )
			return ( LessonSeriesM.descr );
		else if ( cur_series == LessonSeriesS.series )
			return ( LessonSeriesS.descr );
		else if ( cur_series == LessonSeriesN.series )
			return ( LessonSeriesN.descr );
		return ( null );
	}
	public Lesson[] get_lessons() {
		     if ( cur_series == LessonSeriesQ.series )
			return ( LessonSeriesQ.lessons );
		else if ( cur_series == LessonSeriesR.series )
			return ( LessonSeriesR.lessons );
		else if ( cur_series == LessonSeriesT.series )
			return ( LessonSeriesT.lessons );
		else if ( cur_series == LessonSeriesV.series )
			return ( LessonSeriesV.lessons );
		else if ( cur_series == LessonSeriesU.series )
			return ( LessonSeriesU.lessons );
		else if ( cur_series == LessonSeriesD.series )
			return ( LessonSeriesD.lessons );
		else if ( cur_series == LessonSeriesM.series )
			return ( LessonSeriesM.lessons );
		else if ( cur_series == LessonSeriesS.series )
			return ( LessonSeriesS.lessons );
		else if ( cur_series == LessonSeriesN.series )
			return ( LessonSeriesN.lessons );
		return ( null );
	}


	// printout method
	public String toString() {
		String ret_string = "LessonSeriesLibrary{";
		ret_string += "get_num_series()=" + get_num_series()
				+ ",cur_series=\"" + cur_series
				+ "\",get_series()=\"" + get_series()
				+ "\",get_descr()=\"" + get_descr()
				+ "\",get_lessons()@";
		for ( int index = 0; index < get_lessons().length; index++ ) {
			ret_string += "[" + index + "]" + get_lessons()[ index ];
		}
		return ( ret_string + "}" );
	}


	// test code
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		LessonSeriesLibrary ls = new LessonSeriesLibrary();
		for ( int i = 0; i < ls.get_num_series(); i++ ) {
			ls.set_series( ls.get_series( i ));
			System.out.println( "Set series to " + i + ":" );
			System.out.println( ls );
			System.out.println( "" );
		}
	}
}
