//
// JTypist v3.0 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// TutorialGUI class - creates a frame to display a tutorial
//
import java.awt.*;
import java.applet.*;

public class TutorialGUI extends Frame {
	private boolean inAnApplet = true;

	// menubar GUI components
	private MenuBar menu_bar;
	private Menu file_menu, help_menu;
	private MenuItem file_close;

	// GUI components
	private Label title_label;
	private TextArea text_area;

	// constructor initializes the whole GUI set
	public TutorialGUI( boolean inAnApplet ) {
		this.inAnApplet = inAnApplet;

		// create GUI components
		setTitle( "Typist v3.0 Tutorial Window" );
		setLayout( new BorderLayout() );

		// create the menu bar stuff
		menu_bar = new MenuBar();
		setMenuBar( menu_bar );
		// File menu
		file_menu = new Menu( "File" );
		menu_bar.add( file_menu );
		file_close = new MenuItem( "Close Window" );
		file_menu.add( file_close );

		// create the label and text display
		title_label = new Label();
		add( "North", title_label );

		text_area = new TextArea( 12, 80 );
		text_area.setBackground( Color.white );
		text_area.setEditable( false );
		add( "Center", text_area );
	}


	// display the tutorial text from a lesson passed in;
	// supplements the normal show() method
	public void show( Lesson lesson ) {

		// set up the label and text, ignore the description
		title_label.setText( lesson.title );
		text_area.setText( lesson.data );
		show();
	}

	// handle dismiss, close, etc by just hiding ourselves
	private void handle_close_button() {

		// simply just hide this frame from view
		hide();
	}


	// handle GUI component actions and events
	public boolean action( Event evt, Object arg ) {
		if ( evt.target instanceof MenuItem ) {
			if ( evt.target == file_close ) {
				handle_close_button();
			}
		}
		return ( false );
	}
	public boolean handleEvent( Event evt ) {
		if ( evt.id == Event.WINDOW_DESTROY ) {
			handle_close_button();
		}
		return ( super.handleEvent( evt ));
	}


	// test code
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		TutorialGUI tutorial = new TutorialGUI( false );
		tutorial.pack();
		tutorial.show( new Lesson ( Lesson.TUTORIAL,
			"Test lesson title", "unused string",
			"This is test text for a tutorial window" ));
	}
}
