//
// JTypist v3.0 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// Typist class - creates the main program and links everything
// together
//
// Example applet tag:
// <APPLET CODE="Typist" WIDTH=100 HEIGHT=50>
// 	<PARAM NAME="kbtype" VALUE="US">
// 	<PARAM NAME="buttonlabel" VALUE="Run Typist">
// </APPLET>
//
import java.awt.*;
import java.applet.*;

public class Typist extends Applet {

	// keyboard type to use, run button text, and command line
	// flags for the application form of the program
	private String kbtype = KBLayoutUS.kb_id;	// application/applet
	private String buttonlabel = "Run Typist";	// applet
	private boolean kflag = false;			// application
	private boolean hflag = false;			// application
	private boolean vflag = false;			// application

	// usage message, help, and version for the application
	private static final String TRY_USAGE =
	"Try 'Typist -h' for more information."; 
	private static final String USAGE =
	  "Usage: Typist [ options ]\n\n"
	+ "	-k KBTYPE	set keyboard type; valid values are\n"
	+ "			US, UK, and Dvorak\n" 
	+ "	-h		print this message\n"
	+ "	-v		output version information and exit\n";
	private static final String VERSION =
	  "Typist v3.0 (Java), Copyright (C) 1998  Simon Baldwin\n"
	+ "This program comes with ABSOLUTELY NO WARRANTY; for details\n"
	+ "please see the file 'COPYING' supplied with the source code.\n"
	+ "This is free software, and you are welcome to redistribute it\n"
	+ "under certain conditions; again, see 'COPYING' for details.\n"
	+ "This program is released under the GNU General Public License.\n";


	// parse command line arguments into storage for the application
	private void parse_args( String args[] ) {
		for ( int index = 0; index < args.length; index++ ) {
			if ( args[ index ].equals( "-k" )) {
				kflag = true;
				if ( index < args.length - 1 ) {
					kbtype = args[ ++index ];
					if ( ! kbtype.equals( KBLayoutUS.kb_id )
					&& ! kbtype.equals( KBLayoutUK.kb_id )
					&& ! kbtype.equals(
							KBLayoutDvorak.kb_id )) {
						System.err.println(
						"Typist: invalid keyboard type " + kbtype );
						System.err.println( TRY_USAGE );
						System.exit( 1 );
					}
				}
				else {
					System.err.println(
					"Typist: option requires an argument -- k" );
					System.err.println( TRY_USAGE );
					System.exit( 1 );
				}
			}
			else if ( args[ index ].equals( "-h" ))
				hflag = true;
			else if ( args[ index ].equals( "-v" ))
				vflag = true;
			else {
				System.err.println( "Typist: illegal option -- "
						+ args[ index ]);
				System.err.println( TRY_USAGE );
				System.exit( 1 );
			}
		}
	}


	// initialize the applet version of the program
	public void init() {

		// get the parameters - if no kbtype or invalid, just
		// default to initialized value (US)
		String param = getParameter( "kbtype" );
		if ( param != null ) {
			if ( param.equals( KBLayoutUS.kb_id )
					|| param.equals( KBLayoutUK.kb_id )
					|| param.equals( KBLayoutDvorak.kb_id )) {
				kbtype = param;
			}
			else {
				kbtype = KBLayoutUS.kb_id;
				System.out.println(
					"Typist: invalid kbtype parameter" );
				System.out.println(
					"Typist: defaulting to type " + kbtype );
			}
		}
		param = getParameter( "buttonlabel" );
		if ( param != null )
			buttonlabel = param;
		
		// create a get-it-all-going button as the only part
		// of the applet - necessary since the main code makes
		// heavy use of frames and menubars
		Button run_button = new Button( buttonlabel );
		setLayout( new FlowLayout() );
		add( run_button );
	}


	// convenience function to show some startup status where the
	// run up to getting the display on the screen is a slow one
	private void show_status( boolean inAnApplet, String msg ) {
		if ( inAnApplet )
			showStatus( msg );
		else
			System.out.println( msg );
	}


	// start up all the frames of the real program - called by either
	// the action routine of the applet's run button, or by main in
	// the application
	private void start_frames( boolean inAnApplet ) {

		// create the control window, but keep it hidden for
		// the moment
		show_status( inAnApplet, "Creating Control GUI..." );
		ControlGUI control = new ControlGUI( inAnApplet,
				new LessonSeriesLibrary() );

		// create the sub-windows
		show_status( inAnApplet, "Creating Tutorial GUI..." );
		TutorialGUI tutorial = new TutorialGUI( inAnApplet );
		tutorial.pack(); tutorial.hide();

		show_status( inAnApplet, "Generating keyboard layout ("
				+ kbtype + ")..." );
		KBStatistics kbstats = new KBStatistics(
				new KBLayout( kbtype ));
		show_status( inAnApplet, "Creating Statistics GUI..." );
		StatisticsGUI statistics = new StatisticsGUI( inAnApplet,
				kbstats );
		statistics.pack(); statistics.hide();

		show_status( inAnApplet, "Creating Exercise GUI..." );
		ExerciseGUI exercise = new ExerciseGUI( inAnApplet, kbstats );
		exercise.pack(); exercise.hide();

		show_status( inAnApplet, "Creating Help GUI..." );
		HelpGUI help = new HelpGUI( inAnApplet );
		help.pack(); help.hide();

		// if in an applet fake dialogs with frames
		AAboutGUI aabout = null;
		AboutGUI about = null;
		if ( inAnApplet ) {
			show_status( inAnApplet, "Creating About frame..." );
			aabout = new AAboutGUI( inAnApplet );
			aabout.pack(); aabout.hide();
		}
		else {
			show_status( inAnApplet, "Creating About dialog..." );
			about = new AboutGUI( inAnApplet, control, false );
			about.pack(); about.hide();
		}

		// register all the sub-windows with the control window
		show_status( inAnApplet, "Linking the GUIs together..." );
		exercise.register_statistics( statistics );
		if ( inAnApplet )
			control.register_aabout( aabout );
		else
			control.register_about( about );
		control.register_tutorial( tutorial );
		control.register_exercise( exercise );
		control.register_statistics( statistics );
		control.register_help( help );

		// finally reveal the control window
		show_status( inAnApplet, "Typist initialization complete" );
		control.pack(); control.show();

		// if in applet mode, clear the status line
		if ( inAnApplet )
			show_status( inAnApplet, "" );
	}


	// handle the GUI actions in the applet
	public boolean action( Event evt, Object arg ) {
		if ( evt.target instanceof Button ) {

			// must be the run button, so start up the
			// frames and stuff, then sit back and watch
			// the antics
			start_frames( true );
		}
		return ( true );
	}


	// string everything together as an application
	public static void main( String args[] ) {

		// parse the arguments
		Typist typist = new Typist();
		typist.parse_args( args );

		// do the easy stuff with help and version first
		if ( typist.hflag ) {
			System.err.println( USAGE );
			System.exit( 0 );
		}
		if ( typist.vflag ) {
			System.err.println( VERSION );
			System.exit( 0 );
		}

		// create the frames set (no need for the intermediate
		// applet "run" button here)
		typist.start_frames( false );
	}
}
